#! /bin/sh
# IBM Confidential OCO Source Material
# 5630-A36 (C) COPYRIGHT International Business Machines Corp. 2000, 2002
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U.S. Copyright Office.

#####################################################
#                                                   #
# J2C migration tool.                               #
#                                                   #  
# Version 1.0                                       #
#                                                   #
#####################################################

if [ $# -gt 1 ]
then
	# Set the classpath for the tool.
	while [ $# -gt 1 ] && [ "$inputfile" = "" ]
		do 
			case "$1" in 
				-f )
					inputfile=$2 ;;
				-w ) 
					wsdlsource=$2 ;;
				-p ) 
					project=$2 ;;
				-d ) 
					WORKSPACE=$2 ;;
				-e ) 
					ECLIPSE_ROOT=$2 ;;
				-t ) 
					type=$2 ;;
				-s ) 
					summary=$2 ;;
				-o )  
					option=$2 ;;
			esac
	
		shift 2
	done
	
	if [ "$ECLIPSE_ROOT" = "" ]
	then
		ECLIPSE_ROOT="/opt/IBM/Rational/SDP/6.0/eclipse"
	fi

	if [ "$WORKSPACE" = "" ]
	then
		WORKSPACE="/root/IBM/rationalsdp6.0/workspace"
	fi
		
	if [ "$inputfile" = "" ]
	then
		echo ===============================================
		echo Displaying options entered from command line
		echo ===============================================
		echo option: $option
		echo 
		echo type: $type
		echo 
		echo project: $project
		echo 
		echo summary: $summary
		echo 
		echo wsdlsource: $wsdlsource 
		echo 
		echo ================================================
		echo
		echo eclipse_root: $ECLIPSE_ROOT
		echo 
		echo workspace: $WORKSPACE
		echo  
		echo ================================================
		echo 
		
		if [ "$project" != "" ]
		then
			OUTPUT="-output=$project"
		fi

		if [ "$summary" != "" ]
		then
			REPORT="-report=$summary"
		fi

		if [ "$wsdlsource" != "" ]
		then
			WSDL="-wsdl=$wsdlsource" 
		fi

		if [ "$option" != "" ]
		then
			OPTION="-$option"
		fi

		if [ "$type" != "" ]
		then
			TYPE="-$type"
		fi


		echo 
		echo Invoking the command line migration Tool...
		echo 
		
		"$ECLIPSE_ROOT/jre/bin/java" -Xj9  -cp "$ECLIPSE_ROOT/startup.jar" org.eclipse.core.launcher.Main -os linux -ws gtk -data "$WORKSPACE" -application com.ibm.j2c.migration.J2CMigration $WSDL $OUTPUT $TYPE $REPORT $OPTION
	
	else
		echo
		echo eclipse_root: $ECLIPSE_ROOT
		echo 
		echo workspace: $WORKSPACE
		echo  

		FILE="-file=$inputfile"
		
		echo
		echo inputfile: $inputfile
		echo $FILE
		echo
		
		# -clean option only for internal development to pickup fixes by migration.jar plugin.
		# -clean will take a long time , normally do not use -clean
		# ECHO. "$ECLIPSE_ROOT/jre/bin/java" -Xj9  -cp "$ECLIPSE_ROOT/startup.jar" org.eclipse.core.launcher.Main -data "$WORKSPACE" -application com.ibm.j2c.migration.J2CMigration $FILE 
		#
		echo Invoking the command line migration Tool...
		echo

		"$ECLIPSE_ROOT/jre/bin/java" -Xj9  -cp "$ECLIPSE_ROOT/startup.jar" org.eclipse.core.launcher.Main -os linux -ws gtk -data "$WORKSPACE" -application com.ibm.j2c.migration.J2CMigration $FILE 
	fi

else
	echo You should provide at least one input. 

	echo ===========================================================================================
	echo You need to set the eclipse_root as well as workspace inside the J2CMigration.bat first
	echo
	echo
	echo Usage:      J2CMigration.sh 
	echo             -w wsdlsource -d workspace [-p project] [-t type] [-o option] [-s summary] 
	echo
	echo
	echo workspace:  The workspace of where output is generated 
	echo
	echo wsdlsource: The full path of the service WSDL file
	echo             or the full path of the folder that contains one or more
	echo             services WSDL files.
	echo
	echo project:    The name of the project where the migrated artifacts will be generated.
	echo             Do not include a path, just a Name for the project.  
	echo             You can specify web, Java, or EJB project to be created.
	echo             If no project is specified, a default Java project will be created.
	echo             If you do not specify the -p option, then the migrated artifacts
	echo             will be generated to the project specified in the service WSDL file.
	echo
	echo type:       WEB or EJB orJAVA
	echo             Project type of the output project
	echo
	echo option:     databindingonly or commandbean
	echo             databindingonly: Specify this option if you want only data binding 
	echo                              beans to be generated during migration.    
	echo             commandbean:     Specify this option if you want 
	echo                              a command bean to be generated. 
	echo             If you specify databindingonly, 
	echo             the commandbean option will be ignored.
	echo
	echo summary:    The name of migration summary "("without .xml")".
	echo             If none is specified, the default summary file will be 
	echo             j2cmigration_timestamp.xml 
	echo             If the summary file say summary.xml already exists,
	echo             we will write the summary to the summary_timestamp.xml.
	echo
	echo migrationinputfile: The migration file which contains the above options to be
	echo                     passed into the command line migration tool
	echo                     This method is useful when you command line options are too 
	echo                     long. 
	echo 
	echo 
	echo 
	echo =================================================================================
	echo 
	echo Example: 
	echo 
	echo  
	echo J2CMigration.bat -d "/root/myworkspace" -w "/root/mywsdl.wsdl" -p "OutputProject"
	echo J2CMigration.bat  -w "/root/mywsdl.wsdl" -p "OutputProject" -s "MigrationReport"
	echo J2CMigration.bat  -w "/root/mywsdlFolder" -p "OutputProject" -s "MigrationReport"
	echo J2CMigration.bat -w "/root/myfolder" -o databindingonly  
	echo J2CMigration.bat -w "/root/myfolder" -o commandbean -t EJB  
	echo J2CMigration.bat -f "/root/mymigrationinputs"
	echo 
fi
